/************************************************************************
 * Start of Program. Prints out all comments and strings from Parser.c  *
 ************************************************************************/
#include "Parser.h"
#include <stdio.h>    /* printf()         */
#include <stdlib.h>   /* *alloc(), free() */

char *PrintString (Parser &p, char *sp, void *);
char *PrintComment(Parser &p, char *sp, void *);

int main(void)
{
  int   tset_strings;
  int   tset_comments;
  char *buffer;

  Parser p("Parser.cpp");

  tset_strings  = p.AddTokenSet();
  tset_comments = p.AddTokenSet();

  p.SetTokenSet(0);
  p.AddTokenSeparator("\"", 0, tset_strings,  0, PrintString );
  p.AddTokenSeparator("/*", 0, tset_comments, 0, PrintComment);

    /* Set up the token set that will handle the strings */
  p.SetTokenSet(tset_strings);
  p.AddTokenSeparator("\\\\", 0, -1, 1, 0);
  p.AddTokenSeparator("\\\"", 0, -1, 1, 0);
  p.AddTokenSeparator("\"",   0,  0, 0, 0);

    /* Set up the token set that will handle all comments */
  p.SetTokenSet(tset_comments);
  p.AddTokenSeparator("*/", 0, 0, 0, 0);

  p.SetTokenSet(0);

    /* Loop through all the code. GrabToken() will return chunks of code*
     *   so, we need to free it until we get a null buffer/end of file  */
  for(buffer = p.GrabToken(); buffer; buffer = p.GrabToken())
    free(buffer);

  return 0;
}

char *PrintString(Parser &p, char *sp, void *)
{
  char *buffer = p.GrabToken();
  printf("String Found!\n\"%s\"\n\n", buffer);
  free(buffer);

  return sp;
}

char *PrintComment(Parser &p, char *sp, void *)
{
  char *buffer = p.GrabToken();
  printf("Comment Found!\n/*%s*/\n\n", buffer);
  free(buffer);

  return sp;
}
/************************************************************************
 * End of Program                                                       *
 ************************************************************************/
